@@ -1,3 +1,4 @@
+## 2021-10-23 CJS Added trunc.logitP to deal with extreme values of logitP during plotting
 ## 2020-12-15 CJS removed sampfrac from body of code
 ## 2020-12-15 CJS Fixed problem when specifyin u2==NA
 ## 2020-11-07 CJS Allowed user to specify prior for beta coefficient for logitP
@@ -48,15 +49,9 @@
 #' \code{\link{TimeStratPetersenDiagError_fit}} function for cases where
 #' recaptures take place ONLY in the stratum of release, i.e. the diagonal
 #' case.
-#' @param u2 A numeric vector of the number of unmarked fish captured in each
-#' stratum.  These will be expanded by the capture efficiency to estimate the
-#' population size in each stratum. The length of u2 should be between the length of n1 and length n1 + number of columns in m2 -1
+#' @template u2.ND
 #' @template sampfrac
-#' @param jump.after A numeric vector with elements belonging to \code{time}.
-#' In some cases, the spline fitting the population numbers should be allowed
-#' to jump.  For example, the population size could take a jump when hatchery
-#' released fish suddenly arrive at the trap.  The jumps occur AFTER the strata
-#' listed in this argument.
+#' @template jump.after
 #' @template bad.n1
 #' @template bad.m2
 #' @template bad.u2
@@ -77,39 +72,17 @@
 #' are available and 39\% have dropped out or fallen back.
 #' @param marked_available_x See marked_available_n
 #' @template mcmc-parms
-#' @param tauU.alpha One of the parameters along with \code{tauU.beta} for the
-#' prior for the variance of the random noise for the smoothing spline.
-#' @param tauU.beta One of the parameters along with \code{tauU.alpha} for the
-#' prior for the variance of the random noise for the smoothing spline.
-#' @param taueU.alpha One of the parameters along with \code{taueU.beta} for
-#' the prior for the variance of noise around the spline.
-#' @param taueU.beta One of the parameters along with \code{taueU.alpha} for
-#' the prior for the variance of noise around the spline.
-#' @param Delta.max Maximum transition time for marked fish, i.e. all fish
-#' assumed to have moved by Delta.max unit of time
-#' @param tauTT.alpha One of the parameters along with \code{tauTT.beta} for
-#' the prior on 1/var of logit continuation ratio for travel times
-#' @param tauTT.beta One of the parameters along with \code{tauTT.alpha} for
-#' the prior on 1/var of logit continuation ratio for travel times
-#' @param prior.beta.logitP.mean Mean of the prior normal distribution for
-#' logit(catchability) across strata
-#' @param prior.beta.logitP.sd   SD of the prior normal distribution for
-#' logit(catchability) across strata
-#' @param tauP.alpha One of the parameters for the prior for the variance in
-#' logit(catchability) among strata
-#' @param tauP.beta One of the parameters for the prior for the variance in
-#' logit(catchability) among strata
-#' @param run.prob Numeric vector indicating percentiles of run timing should
-#' be computed.
-#' @param debug Logical flag indicating if a debugging run should be made. In
-#' the debugging run, the number of samples in the posterior is reduced
-#' considerably for a quick turn around.
-#' @param debug2 Logical flag indicated if additional debugging information is
-#' produced. Normally the functions will halt at \code{browser()} calls to
-#' allow the user to peek into the internal variables. Not useful except to
-#' package developers.
+#' @template tauU.alpha.beta
+#' @template taueU.alpha.beta
+#' @template Delta.max
+#' @template tauTT.alpha.beta
+#' @template prior.beta.logitP.mean.sd
+#' @template tauP.alpha.beta 
+#' @template run.prob 
+#' @template debug 
 #' @template InitialSeed
 #' @template save.output.to.files
+#' @template trunc.logitP
 #' 
 #' @return An MCMC object with samples from the posterior distribution. A
 #' series of graphs and text file are also created in the working directory.
@@ -141,7 +114,8 @@ TimeStratPetersenNonDiagErrorNPMarkAvail_fit<- function( title="TSPNDENP-avail",
                          run.prob=seq(0,1,.1),  # what percentiles of run timing are wanted 
                          debug=FALSE, debug2=FALSE,
                          InitialSeed=ceiling(stats::runif(1,min=0, max=1000000)),
-                         save.output.to.files=TRUE) {
+                         save.output.to.files=TRUE,
+                         trunc.logitP=15) {
   ## Fit a Time Stratified Petersen model with NON-diagonal entries and with smoothing on U allowing for random error
   ## and fall back after tagging. This is based on the Skeena River study, where only 40/66 (60%) acoustically tagged fish
   ## were observed above the canyon spot and hence 40% of tagged fish never migrated forward of their tagging release spot.
@@ -152,7 +126,7 @@ TimeStratPetersenNonDiagErrorNPMarkAvail_fit<- function( title="TSPNDENP-avail",
   ## strata later. Transisions of marked fish are modelled non-parametrically.
   ##
   
-  version <- '2021-11-01'
+  version <- '2021-11-02'
   options(width=200)
   
   ## Input parameters are
@@ -564,15 +538,24 @@ if(length(prior.beta.logitP.mean) != ncol(logitP.cov) | length(prior.beta.logitP
   results.row.names <- rownames(results$summary)
   etaU.row.index    <- grep("etaU", results.row.names)
   etaU<- results$summary[etaU.row.index,]
-  plot.df$logU =etaU[,"mean"]
-  plot.df$lcl =etaU[,"2.5%"]
-  plot.df$ucl =etaU[,"97.5%"]
+  plot.df$logU    = etaU[,"mean"]
+  plot.df$logUlcl = etaU[,"2.5%"]
+  plot.df$logUucl = etaU[,"97.5%"]
 
 # extract the spline values
   logUne.row.index <- grep("logUne", results.row.names)
   logUne<- results$summary[logUne.row.index,"mean"]
   plot.df$spline <- results$summary[logUne.row.index,"mean"]
+  
+  # add limits to the plot to avoid non-monotone secondary axis problems with extreme values
+  plot.df$logUi     <- pmax(-10 , pmin(20, plot.df$logUi))
+  plot.df$logU      <- pmax(-10 , pmin(20, plot.df$logU ))
+  plot.df$logUlcl   <- pmax(-10 , pmin(20, plot.df$logUlcl  ))
+  plot.df$logUucl   <- pmax(-10 , pmin(20, plot.df$logUucl  ))
+  plot.df$spline    <- pmax(-10 , pmin(20, plot.df$spline))
 
+  
+  
   fit.plot <- ggplot(data=plot.df, aes_(x=~time))+
     ggtitle(title, subtitle="Fitted spline curve with 95% credible intervals for estimated log(U[i])")+
     geom_point(aes_(y=~logUi), color="red", shape=1)+  # open circle
@@ -580,7 +563,7 @@ if(length(prior.beta.logitP.mean) != ncol(logitP.cov) | length(prior.beta.logitP
     ylab("log(U[i]) + 95% credible interval")+
     geom_point(aes_(y=~logU), color="black", shape=19)+
     geom_line (aes_(y=~logU), color="black")+
-    geom_errorbar(aes_(ymin=~lcl, ymax=~ucl), width=.1)+
+    geom_errorbar(aes_(ymin=~logUlcl, ymax=~logUucl), width=.1)+
     geom_line(aes_(y=~spline),linetype="dashed")+
     scale_x_continuous(breaks=seq(min(plot.df$time,na.rm=TRUE),max(plot.df$time, na.rm=TRUE),2))+
     scale_y_continuous(sec.axis = sec_axis(~ exp(.), name="U + 95% credible interval",
@@ -599,7 +582,9 @@ if(length(prior.beta.logitP.mean) != ncol(logitP.cov) | length(prior.beta.logitP
 
   
   ## acf plot
-  logitP.plot <- plot_logitP(title=title, time=new.time, n1=new.n1, m2=expanded.m2, u2=new.u2, logitP.cov=new.logitP.cov, results=results) 
+  logitP.plot <- plot_logitP(title=title, time=new.time, n1=new.n1, m2=expanded.m2, u2=new.u2, 
+                             logitP.cov=new.logitP.cov, results=results,
+                             trunc.logitP=trunc.logitP) 
   if(save.output.to.files)ggsave(plot=logitP.plot, filename=paste(prefix,"-logitP.pdf",sep=""), height=6, width=10, units="in")
   results$plots$logitP.plot <- logitP.plot
   
